mercurial/templatefilters.py
changeset 36830 71f189941791
parent 36607 c6061cadb400
child 36831 82af07e1ae16
--- a/mercurial/templatefilters.py	Tue Mar 06 07:11:24 2018 -0600
+++ b/mercurial/templatefilters.py	Tue Mar 06 07:15:01 2018 -0600
@@ -14,7 +14,6 @@
 from . import (
     encoding,
     error,
-    hbisect,
     node,
     pycompat,
     registrar,
@@ -343,13 +342,15 @@
     return text[:12]
 
 @templatefilter('shortbisect')
-def shortbisect(text):
-    """Any text. Treats `text` as a bisection status, and
+def shortbisect(label):
+    """Any text. Treats `label` as a bisection status, and
     returns a single-character representing the status (G: good, B: bad,
     S: skipped, U: untested, I: ignored). Returns single space if `text`
     is not a valid bisection status.
     """
-    return hbisect.shortlabel(text) or ' '
+    if label:
+        return label[0].upper()
+    return ' '
 
 @templatefilter('shortdate')
 def shortdate(text):